@@ -1,7 +1,9 @@
+from . import utils
 from .base import *
 from .checks import *
 from .command import *
 from .context import *
 from .converters import *
 from .errors import *
-from .utils import *
+from .extension import *
+from .manager import *
