@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 import collections
-import contextlib
 import functools
 import inspect
 import typing
@@ -7,14 +8,19 @@ import typing
 import attrs
 import typing_extensions
 
-import interactions
 from . import context
 from . import converters
 from . import errors
 from .utils import _start_quotes
 from .utils import maybe_coroutine
+from .utils import MISSING
+
+
+if typing.TYPE_CHECKING:
+    from .extension import MolterExtension
 
 __all__ = (
+    "PrefixedCommandParameter",
     "MolterCommand",
     "prefixed_command",
     "prefix_command",
@@ -27,9 +33,6 @@ __all__ = (
 )
 
 
-if typing.TYPE_CHECKING:
-    from .base import MolterExtension
-
 # 3.8+ compatibility
 NoneType = type(None)
 
@@ -63,7 +66,7 @@ class ParameterInfo(typing.TypedDict):
     ]
 
 
-@attrs.define(slots=True)
+@attrs.define()
 class PrefixedCommandParameter:
     """
     An object representing parameters in a prefixed command.
@@ -72,7 +75,7 @@ class PrefixedCommandParameter:
 
     name: str = attrs.field(default=None)
     "The name of the parameter."
-    default: typing.Any = attrs.field(default=interactions.MISSING)
+    default: typing.Any = attrs.field(default=MISSING)
     "The default value of the parameter."
     type: typing.Type = attrs.field(default=None)
     "The type of the parameter."
@@ -98,7 +101,7 @@ class PrefixedCommandParameter:
     @property
     def optional(self) -> bool:
         """Is this parameter optional?"""
-        return self.default != interactions.MISSING
+        return self.default is not MISSING
 
 
 @attrs.define(slots=True)
@@ -328,9 +331,7 @@ def _get_params(
             cmd_param.default = parameter_dict["default"]
         else:
             cmd_param.default = (
-                param.default
-                if param.default is not param.empty
-                else interactions.MISSING
+                param.default if param.default is not param.empty else MISSING
             )
 
         if typing_extensions.get_origin(anno) == converters.Greedy:
@@ -388,7 +389,7 @@ def _get_params(
 async def _convert(
     param: PrefixedCommandParameter, ctx: context.MolterContext, arg: str
 ):
-    converted = interactions.MISSING
+    converted = MISSING
     for converter in param.converters:
         try:
             converted = await maybe_coroutine(converter, ctx, arg)
@@ -400,7 +401,7 @@ async def _convert(
                 raise errors.BadArgument(str(e)) from e
 
     used_default = False
-    if converted == interactions.MISSING:
+    if converted == MISSING:
         if param.optional:
             converted = (
                 await maybe_coroutine(param.default, ctx)
@@ -465,6 +466,8 @@ async def _greedy_convert(
     hash=False,
 )
 class MolterCommand:
+    """The object representing a prefixed command made with Molter."""
+
     extension: typing.Optional["MolterExtension"] = attrs.field(default=None)
     "The extension this command belongs to."
     enabled: bool = attrs.field(default=True)
@@ -472,12 +475,12 @@ class MolterCommand:
     callback: typing.Callable[..., typing.Coroutine] = attrs.field(
         default=None,
     )
-    "The coroutine to be called for this command"
+    "The coroutine to be called for this command."
     name: str = attrs.field()
     "The name of the command."
 
     parameters: typing.List[PrefixedCommandParameter] = attrs.field(factory=list)
-    "The paramters of the command."
+    "The parameters of the command."
     aliases: typing.List[str] = attrs.field(
         factory=list,
     )
@@ -485,17 +488,23 @@ class MolterCommand:
     hidden: bool = attrs.field(
         default=False,
     )
-    "If `True`, the default help command does not show this in the help output."
+    """
+    If ``True``, the default help command does not show this in the help output.
+    Defaults to ``False``.
+    """
     ignore_extra: bool = attrs.field(default=True)
     """
-    If `True`, ignores extraneous strings passed to a command if all its
-    requirements are met (e.g. ?foo a b c when only expecting a and b).
-    Otherwise, an error is raised. Defaults to True.
+    If ``True``, ignores extraneous strings passed to a command if all its
+    requirements are met (e.g. ``?foo a b c`` when only expecting ``a`` and ``b``).
+    Otherwise, an error is raised. Defaults to ``True``.
     """
     hierarchical_checking: bool = attrs.field(default=True)
-    """If `True` and if the base of a subcommand, every subcommand underneath
+    """
+    If ``True`` and if the base of a subcommand, every subcommand underneath
     it will run this command's checks and cooldowns before its own. Otherwise,
-    only the subcommand's checks are checked."""
+    only the subcommand's checks are checked.
+    Defaults to ``True``.
+    """
 
     help: typing.Optional[str] = attrs.field(default=None)
     """The long help text for the command."""
@@ -508,7 +517,7 @@ class MolterCommand:
     subcommands: typing.Dict[str, typing_extensions.Self] = attrs.field(
         factory=dict,
     )
-    "A dict of all subcommands for the command."
+    "A mapping of all names/aliases of a subcommand to their subcommand for the command."
 
     checks: typing.List[
         typing.Callable[
@@ -582,7 +591,7 @@ class MolterCommand:
         return " ".join(name_deq)
 
     @property
-    def all_commands(self) -> typing.FrozenSet[typing_extensions.Self]:
+    def all_subcommands(self) -> typing.FrozenSet[typing_extensions.Self]:
         """Returns all unique subcommands underneath this command."""
         return frozenset(self.subcommands.values())
 
@@ -647,15 +656,15 @@ class MolterCommand:
 
     def _parse_parameters(self) -> None:
         """
-        Parses the parameters that this command has into a form molter can use.
+        Parses the parameters that this command has into a form Molter can use.
 
-        This is purposely seperated like this to allow "lazy parsing" - parsing
+        This is purposely separated like this to allow "lazy parsing" - parsing
         as the command is added to a client rather than being parsed immediately.
         This allows variables like "self" to be filtered out, and allows
         for decorators that modify parameters to be parsed later, all at once.
 
         This is called automatically if you add the command via
-        `MolterManager.add_prefixed_command`, but it is up to the user to remember
+        ``MolterManager.add_prefixed_command``, but it is up to the user to remember
         to put the extension in, if needed.
         """
 
@@ -673,7 +682,7 @@ class MolterCommand:
         )
 
         # we need to deal with subcommands too
-        for command in self.all_commands:
+        for command in self.all_subcommands:
             command._parse_parameters()
 
     def is_subcommand(self) -> bool:
@@ -685,7 +694,7 @@ class MolterCommand:
         Adds a command as a subcommand to this command.
 
         Args:
-            cmd (`MolterCommand`): The command to add
+            cmd (MolterCommand): The command to add
         """
         cmd.parent = self  # just so we know this is a subcommand
 
@@ -710,7 +719,7 @@ class MolterCommand:
         If an alias is specified, only the alias will be removed.
 
         Args:
-            name (`str`): The command to remove.
+            name (str): The command to remove.
         """
         command = self.subcommands.pop(name, None)
 
@@ -728,9 +737,9 @@ class MolterCommand:
         """
         Gets a subcommand from this command. Can get subcommands of subcommands if needed.
         Args:
-            name (`str`): The command to search for.
+            name (str): The command to search for.
         Returns:
-            `MolterCommand`: The command object, if found.
+            MolterCommand: The command object, if found.
         """
         if " " not in name:
             return self.subcommands.get(name)
@@ -767,7 +776,7 @@ class MolterCommand:
         A decorator to register an error callback for a command.
 
         Args:
-            error_callback (`Callable`):
+            error_callback (Callable):
             The error callback to register. It must be an asynchronous function that
             takes in MolterContext and an exception.
         """
@@ -799,50 +808,36 @@ class MolterCommand:
         ] = None,
     ) -> typing.Callable[..., typing_extensions.Self]:
         """
-        A decorator to declare a subcommand for a molter prefixed command.
+        A decorator to declare a subcommand for a Molter prefixed command.
 
         Parameters:
-            name (`str`, optional): The name of the command.
-            Defaults to the name of the coroutine.
-
-            aliases (`list[str]`, optional): The list of aliases the
-            command can be invoked under.
-
-            help (`str`, optional): The long help text for the command.
-            Defaults to the docstring of the coroutine, if there is one.
-
-            brief (`str`, optional): The short help text for the command.
-            Defaults to the first line of the help text, if there is one.
-
-            usage(`str`, optional): A string displaying how the command
-            can be used. If no string is set, it will default to the
-            command's signature. Useful for help commands.
-
-            enabled (`bool`, optional): Whether this command can be run
-            at all. Defaults to True.
-
-            hidden (`bool`, optional): If `True`, the default help
-            command (when it is added) does not show this in the help
-            output. Defaults to False.
-
-            ignore_extra (`bool`, optional): If `True`, ignores extraneous
-            strings passed to a command if all its requirements are met
-            (e.g. ?foo a b c when only expecting a and b).
-            Otherwise, an error is raised. Defaults to True.
-
-            hierarchical_checking (`bool`, optional): If `True` and if the
-            base of a subcommand, every subcommand underneath it will run this
-            command's checks before its own. Otherwise, only the subcommand's
-            checks are checked. Defaults to True.
-
-            type_to_converter (`dict[type, type[MolterConverter]]`, optional): A dict
-            that associates converters for types. This allows you to use
-            native type annotations without needing to use `typing.Annotated`.
-            If this is not set, only interactions.py classes will be converted using
-            built-in converters.
+            name: The name of the command. Defaults to the name of the coroutine.
+            aliases: The list of aliases the command can be invoked under.
+            help: The long help text for the command. \
+                Defaults to the docstring of the coroutine, if there is one.
+            brief: The short help text for the command. \
+                Defaults to the first line of the help text, if there is one.
+            usage: A string displaying how the command can be used. If no \
+                string is set, it will default to the command's signature. \
+                Useful for help commands.
+            enabled: Whether this command can be run at all. Defaults to ``True``.
+            hidden: If ``True``, the default help command (when it is added) \
+                does not show this in the help output. Defaults to ``False``.
+            ignore_extra: If ``True``, ignores extraneous strings passed to a \
+                command if all its requirements are met (e.g. ``?foo a b c`` \
+                when only expecting ``a`` and ``b``). Otherwise, an error is \
+                raised. Defaults to ``True``.
+            hierarchical_checking: If ``True`` and if the base of a subcommand, \
+                every subcommand underneath it will run this command's checks \
+                before its own. Otherwise, only the subcommand's checks are \
+                checked. Defaults to ``True``.
+            type_to_converter: A dict that associates converters for types. \
+                This allows you to use native type annotations without needing \
+                to use ``typing.Annotated``. If this is not set, only interactions.py \
+                classes will be converted using built-in converters.
 
         Returns:
-            `molter.MolterCommand`: The command object.
+            MolterCommand: The command object.
         """
 
         def wrapper(func):
@@ -879,7 +874,7 @@ class MolterCommand:
         Runs the command with checks.
 
         Args:
-            ctx (`context.MolterContext`): The context to use for this command.
+            ctx: The context to use for this command.
         """
         await self._run_checks(ctx)
         return await self.invoke(ctx)
@@ -889,7 +884,7 @@ class MolterCommand:
         Runs the callback of this command.
 
         Args:
-            ctx (`context.MolterContext`): The context to use for this command.
+            ctx: The context to use for this command.
         """
         # sourcery skip: remove-empty-nested-block, remove-redundant-if, remove-unnecessary-else
         callback = self.callback
@@ -1002,50 +997,36 @@ def prefixed_command(
     ] = None,
 ) -> typing.Callable[..., MolterCommand]:
     """
-    A decorator to declare a coroutine as a molter prefixed command.
+    A decorator to declare a coroutine as a Molter prefixed command.
 
     Parameters:
-        name (`str`, optional): The name of the command.
-        Defaults to the name of the coroutine.
-
-        aliases (`list[str]`, optional): The list of aliases the
-        command can be invoked under.
-
-        help (`str`, optional): The long help text for the command.
-        Defaults to the docstring of the coroutine, if there is one.
-
-        brief (`str`, optional): The short help text for the command.
-        Defaults to the first line of the help text, if there is one.
-
-        usage(`str`, optional): A string displaying how the command
-        can be used. If no string is set, it will default to the
-        command's signature. Useful for help commands.
-
-        enabled (`bool`, optional): Whether this command can be run
-        at all. Defaults to True.
-
-        hidden (`bool`, optional): If `True`, the default help
-        command (when it is added) does not show this in the help
-        output. Defaults to False.
-
-        ignore_extra (`bool`, optional): If `True`, ignores extraneous
-        strings passed to a command if all its requirements are met
-        (e.g. ?foo a b c when only expecting a and b).
-        Otherwise, an error is raised. Defaults to True.
-
-        hierarchical_checking (`bool`, optional): If `True` and if the
-        base of a subcommand, every subcommand underneath it will run this
-        command's checks before its own. Otherwise, only the subcommand's
-        checks are checked. Defaults to True.
-
-        type_to_converter (`dict[type, type[MolterConverter]]`, optional): A dict
-        that associates converters for types. This allows you to use
-        native type annotations without needing to use `typing.Annotated`.
-        If this is not set, only interactions.py classes will be converted using
-        built-in converters.
+        name: The name of the command. Defaults to the name of the coroutine.
+        aliases: The list of aliases the command can be invoked under.
+        help: The long help text for the command. \
+            Defaults to the docstring of the coroutine, if there is one.
+        brief: The short help text for the command. \
+            Defaults to the first line of the help text, if there is one.
+        usage: A string displaying how the command can be used. If no \
+            string is set, it will default to the command's signature. \
+            Useful for help commands.
+        enabled: Whether this command can be run at all. Defaults to ``True``.
+        hidden: If ``True``, the default help command (when it is added) \
+            does not show this in the help output. Defaults to ``False``.
+        ignore_extra: If ``True``, ignores extraneous strings passed to a \
+            command if all its requirements are met (e.g. ``?foo a b c`` \
+            when only expecting ``a`` and ``b``). Otherwise, an error is \
+            raised. Defaults to ``True``.
+        hierarchical_checking: If ``True`` and if the base of a subcommand, \
+            every subcommand underneath it will run this command's checks \
+            before its own. Otherwise, only the subcommand's checks are \
+            checked. Defaults to ``True``.
+        type_to_converter: A dict that associates converters for types. \
+            This allows you to use native type annotations without needing \
+            to use ``typing.Annotated``. If this is not set, only interactions.py \
+            classes will be converted using built-in converters.
 
     Returns:
-        `molter.MolterCommand`: The command object.
+        MolterCommand: The command object.
     """
 
     def wrapper(func):
@@ -1068,11 +1049,14 @@ def prefixed_command(
 
 
 prefix_command = prefixed_command
+"""An alias for :meth:`prefixed_command`."""
 text_command = prefixed_command
+"""An alias for :meth:`prefixed_command`."""
 text_based_command = prefixed_command
+"""An alias for :meth:`prefixed_command`."""
 
 
-# molter command typevar - can be the function or the command
+# Molter command typevar - can be the function or the command
 MCT = typing.TypeVar("MCT", typing.Callable, MolterCommand)
 
 
@@ -1081,13 +1065,15 @@ def register_converter(
 ) -> typing.Callable[..., MCT]:
     """
     A decorator that allows you to register converters for a type for a specific command.
-    This allows for native type annotations without needing to use `typing(_extensions).Annotated`.
+    This allows for native type annotations without needing to use ``typing(_extensions).Annotated``.
+
     Args:
-        type_ (`type`): The type to register for.
-        converter (`type[MolterConverter]`): The converter to use for the type.
+        type_: The type to register for.
+        converter: The converter to use for the type.
+
     Returns:
-        `Callable | MolterCommand`: Either the callback or the command.
-        If this is used after using the `molter.prefixed_command` decorator, it will be a command.
+        typing.Union[typing.Callable, MolterCommand]: Either the callback or the command.
+        If this is used after using the :meth:`prefixed_command` decorator, it will be a command.
         Otherwise, it will be a callback.
     """
     if not isinstance(converter, converters.MolterConverter):
@@ -1109,11 +1095,12 @@ def globally_register_converter(
 ) -> None:
     """
     A decorator that allows you to register converters for commands decorated/made after this is run.
-    This allows for native type annotations without needing to use `typing.Annotated`.
+    This allows for native type annotations without needing to use ``typing(_extensions).Annotated``.
     Note that this does not retroactively register converters for commands already made.
+
     Args:
-        anno_type (`type`): The type to register for.
-        converter (`type[MolterConverter]`): The converter to use for the type.
+        anno_type: The type to register for.
+        converter: The converter to use for the type.
     """
     if not isinstance(converter, converters.MolterConverter):
         raise ValueError('Converter provided did not have a "convert" method.')
@@ -1126,38 +1113,38 @@ def globally_register_converter(
 def prefixed_parameter(
     parameter_name: str,
     *,
-    default: typing.Any = interactions.MISSING,
+    default: typing.Any = MISSING,
     factory: typing.Optional[
         typing.Callable[[context.MolterContext], typing.Any]
     ] = None,
 ) -> typing.Callable[..., MCT]:
     """
-    A decorator that allows you to adjust a parameter in a prefixed comamnd.
+    A decorator that allows you to adjust a parameter in a prefixed command.
 
     Args:
-        parameter_name (`str`): The parameter in the command to edit.
-        default (`Any`, optional): The default value the parameter should have.
-        factory (`Callable[MolterContext]`, optional): A factory function to use
-        if no argument is provided for this parameter. The function can be asynchronous
-        or synchronous, and should take in solely a `MolterContext`.
+        parameter_name: The parameter in the command to edit.
+        default: The default value the parameter should have.
+        factory: A factory function to use if no argument is provided for this \
+            parameter. The function can be asynchronous or synchronous, and should \
+            take in solely a :class:`.MolterContext`.
 
     Returns:
-        `Callable | MolterCommand`: Either the callback or the command.
-        If this is used after using the `molter.prefixed_command` decorator, it will be a command.
+        typing.Union[typing.Callable, MolterCommand]: Either the callback or the command.
+        If this is used after using the :meth:`prefixed_command` decorator, it will be a command.
         Otherwise, it will be a callback.
     """
 
     def wrapper(command: MCT) -> MCT:
         parameter_info: ParameterInfo = {}  # type: ignore
 
-        if factory is not None and default is not interactions.MISSING:
+        if factory is not None and default is not MISSING:
             raise ValueError("You cannot provide both a default and a factory.")
-        elif factory is None and default is interactions.MISSING:
+        elif factory is None and default is MISSING:
             raise ValueError("You must provide either a default or a factory.")
 
         if factory is not None:
             parameter_info["default"] = factory
-        elif default is not interactions.MISSING:
+        elif default is not MISSING:
             parameter_info["default"] = default
 
         if hasattr(command, "_parameters_info"):
@@ -1184,12 +1171,12 @@ def ext_error_handler(
     error_callback: typing.Optional[EEH] = None,
 ) -> typing.Union[typing.Callable[[EEH], EEH], EEH]:
     """
-    A decorator to register an error callback for a MolterExtension.
+    A decorator to register an error callback for a :class:`.MolterExtension`.
 
     Args:
-        error_callback (`Callable`):
-        The error callback to register. It must be an asynchronous function that
-        takes in `self`, MolterContext and an exception.
+        error_callback (Callable): The error callback to register. \
+            It must be an asynchronous function that takes in ``self``, \
+            :class:`.MolterContext` and an :class:`Exception`.
     """
 
     def decorator(error_callback: EEH):
