@@ -8,7 +8,7 @@ import interactions
 import interactions.api.error as inter_errors
 
 if typing.TYPE_CHECKING:
-    from .base import MolterExtension
+    from .extension import MolterExtension
     from .command import MolterCommand
 
 __all__ = (
@@ -29,6 +29,7 @@ __all__ = (
     "permissions",
     "Typing",
     "DeferredTyping",
+    "MISSING",
 )
 
 # most of these come from naff
@@ -60,7 +61,7 @@ def _wrap_recursive(cmd: "MolterCommand", ext: "MolterExtension"):
     if cmd.error_callback:
         cmd.error_callback = functools.partial(cmd.error_callback, ext)
 
-    for subcommand in cmd.all_commands:
+    for subcommand in cmd.all_subcommands:
         new_sub = _wrap_recursive(subcommand, ext)
 
         names = [subcommand.name] + subcommand.aliases
@@ -75,8 +76,8 @@ def remove_prefix(string: str, prefix: str) -> str:
     Removes a prefix from a string if present.
 
     Args:
-        string (`str`): The string to remove the prefix from.
-        prefix (`str`): The prefix to remove.
+        string: The string to remove the prefix from.
+        prefix: The prefix to remove.
 
     Returns:
         The string without the prefix.
@@ -89,8 +90,8 @@ def remove_suffix(string: str, suffix: str) -> str:
     Removes a suffix from a string if present.
 
     Args:
-        string (`str`): The string to remove the suffix from.
-        suffix (`str`): The suffix to remove.
+        string: The string to remove the suffix from.
+        suffix: The suffix to remove.
 
     Returns:
         The string without the suffix.
@@ -117,13 +118,12 @@ def when_mentioned_or(
     """
     Returns a list of the bot's mentions plus whatever prefixes are provided.
 
-    This is intended to be used with initializing molter. If you wish to use
-    it in your own function, you will need to do something similar to:
-
-    `await when_mentioned_or(*prefixes)(bot, msg)`
+    This is intended to be used with initializing Molter. If you wish to use
+    it in your own function, you will need to do something similar to
+    ``await when_mentioned_or(*prefixes)(bot, msg)``.
 
     Args:
-        prefixes (`str`): Prefixes to include alongside mentions.
+        prefixes: Prefixes to include alongside mentions.
 
     Returns:
         A list of the bot's mentions plus whatever prefixes are provided.
@@ -136,7 +136,17 @@ def when_mentioned_or(
 
 
 async def maybe_coroutine(func: typing.Callable, *args, **kwargs):
-    """Allows running either a coroutine or a function."""
+    """
+    Allows running either a coroutine or a function.
+
+    Args:
+        func: The function to run.
+        args: Arguments to pass to the function.
+        kwargs: Keyword arguments to pass to the function.
+
+    Returns:
+        Whatever the function returns.
+    """
     if inspect.iscoroutinefunction(func):
         return await func(*args, **kwargs)
     else:
@@ -177,7 +187,7 @@ def get_args_from_str(input: str) -> typing.List[str]:
     Get arguments from an input string.
 
     Args:
-        input (`str`): The string to process.
+        input: The string to process.
     Returns:
         A list of arguments.
     """
@@ -186,10 +196,10 @@ def get_args_from_str(input: str) -> typing.List[str]:
 
 def get_first_word(text: str) -> typing.Optional[str]:
     """
-    Get a the first word in a string, regardless of whitespace type.
+    Gets the first word in a string, regardless of whitespace type.
 
     Args:
-        text (`str`): The text to process.
+        text: The text to process.
     Returns:
         The first word, if found.
     """
@@ -203,7 +213,7 @@ def escape_mentions(content: str) -> str:
     This does not escape channel mentions as they do not ping anybody.
 
     Args:
-        content (`str`): The string to escape.
+        content: The string to escape.
     Returns:
         The escaped string.
     """
@@ -222,8 +232,7 @@ def guild_permissions(
     permission overwrites as a base.
 
     Returns:
-        `interactions.Permissions`: The guild permissions for the member
-        that sent the message.
+        The guild permissions for the member that sent the message.
     """
 
     if int(member.id) == guild.owner_id:
@@ -304,8 +313,7 @@ def permissions(
     permission overwrites as a base.
 
     Returns:
-        `interactions.Permissions`: The permissions for the member
-        that sent the message.
+        The permissions for the member that sent the message.
     """
 
     if not guild or isinstance(member, interactions.User):
@@ -322,8 +330,8 @@ class Typing:
     as long as long as the wrapped operation takes.
 
     Args:
-        http (`interactions.HTTPClient`): The HTTP client to use.
-        channel_id (`int`): The ID of the channel to send the typing state to.
+        http: The HTTP client to use.
+        channel_id: The ID of the channel to send the typing state to.
     """
 
     __slots__ = ("_http", "channel_id", "_stop", "task")
@@ -353,8 +361,8 @@ class DeferredTyping:
     A dummy context manager to defer an interaction and then do nothing.
 
     Args:
-        interaction (`interactions.CommandContext`): The interaction to defer.
-        ephemeral (`bool`, optional) Whether the response is hidden or not.
+        interaction: The interaction to defer.
+        ephemeral: Whether the response is hidden or not.
     """
 
     __slots__ = ("interaction", "ephemeral")
@@ -370,3 +378,44 @@ class DeferredTyping:
 
     async def __aexit__(self, *_) -> None:
         pass
+
+
+class _BetterMissing(object):
+    _instance = None
+
+    def __new__(cls, *args, **kwargs):
+        if not isinstance(cls._instance, cls):
+            cls._instance = object.__new__(cls, *args, **kwargs)
+        return cls._instance
+
+    def __eq__(self, other) -> bool:
+        return self.__class__ == other.__class__
+
+    def __bool__(self) -> bool:
+        return False
+
+    def __hash__(self) -> int:
+        return 0
+
+    def __repr__(self) -> str:
+        return "MISSING"
+
+
+MISSING = _BetterMissing()
+"""
+A sentinel to represent a 'missing' value in Molter when ``None`` cannot be used.
+This differs from
+:class:`interactions.MISSING <interactions.api.models.attrs_utils.MISSING>`
+in that it has a different ``__repr__`` and a few other nice extras. It also
+ensures behavior of it isn't affected by a change in ``interactions.py``.
+"""
+
+
+async def _async_transform_missing(
+    func: typing.Callable[..., typing.Awaitable[T]], **kwargs
+) -> T:
+    for name, value in kwargs.items():
+        if value is MISSING:
+            kwargs[name] = interactions.MISSING
+
+    return await func(**kwargs)
